Builder

Struct Builder 

pub struct Builder { /* private fields */ }
Device builder.

Implementations

Source

impl Builder

pub fn open<P: AsRef<Path>>(path: P) -> Res<Self>

Create a builder from the specified path.

pub fn default() -> Res<Self>

Create a builder from the default path taken from udev.

pub fn name<T: AsRef<str>>(self, value: T) -> Res<Self>

Set the name.

Examples found in repository?
examples/hello.rs (line 9)
7fn main() {
8	let mut device = uinput::default().unwrap()
9		.name("test").unwrap()
10		.event(uinput::event::Keyboard::All).unwrap()
11		.create().unwrap();
12
13	thread::sleep(Duration::from_secs(1));
14
15	device.click(&keyboard::Key::H).unwrap();
16	device.click(&keyboard::Key::E).unwrap();
17	device.click(&keyboard::Key::L).unwrap();
18	device.click(&keyboard::Key::L).unwrap();
19	device.click(&keyboard::Key::O).unwrap();
20	device.click(&keyboard::Key::Space).unwrap();
21	device.click(&keyboard::Key::W).unwrap();
22	device.click(&keyboard::Key::O).unwrap();
23	device.click(&keyboard::Key::R).unwrap();
24	device.click(&keyboard::Key::L).unwrap();
25	device.click(&keyboard::Key::D).unwrap();
26	device.click(&keyboard::Key::Enter).unwrap();
27
28	device.synchronize().unwrap();
29}
pub fn bus(self, value: u16) -> Self

Set the bus type.

pub fn vendor(self, value: u16) -> Self

Set the vendor ID.

pub fn product(self, value: u16) -> Self

Set the product ID.

pub fn version(self, value: u16) -> Self

Set the version.

pub fn event<T: Into<Event>>(self, value: T) -> Res<Self>

Enable the given event.

Examples found in repository?
examples/hello.rs (line 10)
7fn main() {
8	let mut device = uinput::default().unwrap()
9		.name("test").unwrap()
10		.event(uinput::event::Keyboard::All).unwrap()
11		.create().unwrap();
12
13	thread::sleep(Duration::from_secs(1));
14
15	device.click(&keyboard::Key::H).unwrap();
16	device.click(&keyboard::Key::E).unwrap();
17	device.click(&keyboard::Key::L).unwrap();
18	device.click(&keyboard::Key::L).unwrap();
19	device.click(&keyboard::Key::O).unwrap();
20	device.click(&keyboard::Key::Space).unwrap();
21	device.click(&keyboard::Key::W).unwrap();
22	device.click(&keyboard::Key::O).unwrap();
23	device.click(&keyboard::Key::R).unwrap();
24	device.click(&keyboard::Key::L).unwrap();
25	device.click(&keyboard::Key::D).unwrap();
26	device.click(&keyboard::Key::Enter).unwrap();
27
28	device.synchronize().unwrap();
29}
pub fn max(self, value: i32) -> Self

Set the maximum value for the previously enabled absolute event.

pub fn min(self, value: i32) -> Self

Set the minimum value for the previously enabled absolute event.

pub fn fuzz(self, value: i32) -> Self

Set the fuzz value for the previously enabled absolute event.

pub fn flat(self, value: i32) -> Self

Set the flat value for the previously enabled absolute event.

pub fn create(self) -> Res<Device>

Create the defined device.

Examples found in repository?
examples/hello.rs (line 11)
7fn main() {
8	let mut device = uinput::default().unwrap()
9		.name("test").unwrap()
10		.event(uinput::event::Keyboard::All).unwrap()
11		.create().unwrap();
12
13	thread::sleep(Duration::from_secs(1));
14
15	device.click(&keyboard::Key::H).unwrap();
16	device.click(&keyboard::Key::E).unwrap();
17	device.click(&keyboard::Key::L).unwrap();
18	device.click(&keyboard::Key::L).unwrap();
19	device.click(&keyboard::Key::O).unwrap();
20	device.click(&keyboard::Key::Space).unwrap();
21	device.click(&keyboard::Key::W).unwrap();
22	device.click(&keyboard::Key::O).unwrap();
23	device.click(&keyboard::Key::R).unwrap();
24	device.click(&keyboard::Key::L).unwrap();
25	device.click(&keyboard::Key::D).unwrap();
26	device.click(&keyboard::Key::Enter).unwrap();
27
28	device.synchronize().unwrap();
29}